<?php
/*
 Plugin Name: Tickera - Tickets table content management
 Plugin URI: http://tickera.com/
 Description: Options to display or hide specific information in the table of purchased tickets
 Author: Tickera.com
 Author URI: http://tickera.com/
 Version: 1.0
 TextDomain: tc_table_options
 Domain Path: /languages/
 Copyright 2023 Tickera (http://tickera.com/)
*/

if ( !defined( 'ABSPATH' ) )
    exit; // Exit if accessed directly

add_filter('tc_settings_general_sections','tc_tickets_table_settings', 11, 2 );

function tc_tickets_table_settings( $sections ) {

    $sections[] = [
        'name' => 'tickets_table_settings',
        'title' => __( 'Tickets table content options', 'tc_table_options' ),
        'description' => '',
    ];

    return $sections;
}

add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_show_event_title');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_show_event_date_time');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_show_event_location');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_show_ticket_type');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_remove_name');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_allow_download');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_include_qr');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_qr_size');

if (is_plugin_active('custom-forms/tickera-custom-forms.php')) {
    add_filter('tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_show_custom_forms');
}

function tc_general_settings_miscellaneous_fields_show_event_title( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_show_event_title',
        'field_title'	 => __( 'Show event title?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'yes',
        'tooltip'		 => __('Show or hide event title in the table of purchased tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings'
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_remove_name         	 = isset( $tc_get_option[ 'tc_table_option_show_event_title' ] ) ? $tc_get_option[ 'tc_table_option_show_event_title' ] : '';

if ($tc_remove_name === "no") {
    require_once(dirname(__FILE__) . '/includes/disable-event-title.php');
}

function tc_general_settings_miscellaneous_fields_show_event_date_time( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_show_event_date_time',
        'field_title'	 => __( 'Show event start date/time?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'no',
        'tooltip'		 => __('Show or hide event start date/time in the table of purchased tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings',
        'conditional' => array(
            'field_name' => 'tc_table_option_show_event_title',
            'field_type' => 'radio',
            'value' => 'no',
            'action' => 'hide'
        )
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_show_event_date_time     = isset( $tc_get_option[ 'tc_table_option_show_event_date_time' ] ) ? $tc_get_option[ 'tc_table_option_show_event_date_time' ] : '';

if ($tc_show_event_date_time === "yes") {
    require_once(dirname(__FILE__) . '/includes/show-event-date-time.php');
}



function tc_general_settings_miscellaneous_fields_show_event_location( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_show_event_location',
        'field_title'	 => __( 'Show event location?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'no',
        'tooltip'		 => __('Show or hide event location in the table of purchased tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings',
        'conditional' => array(
            'field_name' => 'tc_table_option_show_event_title',
            'field_type' => 'radio',
            'value' => 'no',
            'action' => 'hide'
        )
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_show_event_location      = isset( $tc_get_option[ 'tc_table_option_show_event_location' ] ) ? $tc_get_option[ 'tc_table_option_show_event_location' ] : '';

if ($tc_show_event_location === "yes") {
    require_once(dirname(__FILE__) . '/includes/show-event-location.php');
}

function tc_general_settings_miscellaneous_fields_show_ticket_type( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_remove_ticket_type',
        'field_title'	 => __( 'Show ticket type title?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'yes',
        'tooltip'		 => __('Show or hide ticket type title','tc_table_options'),
        'section'		 => 'tickets_table_settings'
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_show_ticket_type       = isset( $tc_get_option[ 'tc_table_option_remove_ticket_type' ] ) ? $tc_get_option[ 'tc_table_option_remove_ticket_type' ] : '';

if ($tc_show_ticket_type === "no") {
    require_once(dirname(__FILE__) . '/includes/disable-ticket-type.php');
}

function tc_general_settings_miscellaneous_fields_remove_name( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_remove_name',
        'field_title'	 => __( 'Show attendee first and last name in the table?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'yes',
        'tooltip'		 => __('Choose whether to include download link so customers can download their tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings'
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_remove_name         	 = isset( $tc_get_option[ 'tc_table_option_remove_name' ] ) ? $tc_get_option[ 'tc_table_option_remove_name' ] : '';

if ($tc_remove_name === "no") {
    require_once(dirname(__FILE__) . '/includes/disable-name.php');
}

function tc_general_settings_miscellaneous_fields_allow_download( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_allow_download',
        'field_title'	 => __( 'Allow customers to download tickets?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'yes',
        'tooltip'		 => __('Choose whether to include download link so customers can download their tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings',
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_allow_download_enabled	 = isset( $tc_get_option[ 'tc_table_option_allow_download' ] ) ? $tc_get_option[ 'tc_table_option_allow_download' ] : '';

if ($tc_allow_download_enabled === "no") {
    require_once(dirname(__FILE__) . '/includes/disable-download.php');
}


function tc_general_settings_miscellaneous_fields_include_qr( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_include_qr',
        'field_title'	 => __( 'Include QR code in table of purchased tickets?', 'tc_table_options' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => 'no',
        'tooltip'		 => __('This is not related to QR code on the ticket itself but rather relates to whether QR code should be included in the table of purchased tickets','tc_table_options'),
        'section'		 => 'tickets_table_settings'
    );
    return $fields;
}

$tc_get_option			     = get_option( 'tc_general_setting', false );
$tc_table_option_include_qr	 = isset( $tc_get_option[ 'tc_table_option_include_qr' ] ) ? $tc_get_option[ 'tc_table_option_include_qr' ] : '';

if ($tc_table_option_include_qr === "yes") {
    require_once(dirname(__FILE__) . '/includes/include-qr.php');
}


function tc_general_settings_miscellaneous_fields_qr_size( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_table_option_qr_size',
        'field_title'	 => __( 'Enter the size of QR code', 'tc_table_options' ),
        'field_type'     => 'text',
        'default_value'	 => __('ENTER VALUE', 'tc_table_options'),
        'tooltip'		 => __('Recommended size is from 100 to 200','tc_table_options'),
        'section'		 => 'tickets_table_settings',
        'conditional' => array(
            'field_name' => 'tc_table_option_include_qr',
            'field_type' => 'radio',
            'value' => 'no',
            'action' => 'hide'
        ),
        'required' => true,
        'number' => true
    );
    return $fields;
}


function tc_general_settings_miscellaneous_fields_show_custom_forms( $fields ){

        $fields [] = array(
            'field_name' => 'tc_table_option_include_custom_forms',
            'field_title' => __('Show values from Custom Forms?', 'tc_table_options'),
            'field_type' => 'function',
            'function' => 'tc_yes_no',
            'default_value' => 'no',
            'tooltip' => __('Show or hide attendee information collected using Custom Forms add-on'),
            'section' => 'tickets_table_settings'
        );
        return $fields;
}

$tc_get_option			           = get_option( 'tc_general_setting', false );
$tc_table_option_show_custom_forms = isset( $tc_get_option[ 'tc_table_option_include_custom_forms' ] ) ? $tc_get_option[ 'tc_table_option_include_custom_forms' ] : '';

if ($tc_table_option_show_custom_forms === "yes") {
    require_once(dirname(__FILE__) . '/includes/show-custom-forms.php');
}